<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: MyThemeShop Popular Posts
	Version: 2.0.1
	
-----------------------------------------------------------------------------------*/
if( ! class_exists( 'mts_popular_posts_widget' ) ){
	class mts_popular_posts_widget extends WP_Widget {

		public function __construct() {
			parent::__construct(
		 		'mts_popular_posts_widget',
				sprintf( __('%sPopular Posts', 'myblog' ), MTS_THEME_WHITE_LABEL ? '' : 'MTS ' ),
				array( 'description' => __( 'Displays most Popular Posts with Thumbnail.', 'myblog' ) )
			);
		}

	 	public function form( $instance ) {
			$defaults = array(
				'title_length' => 20,
				'image_type' => 'author_img',
				'author_name' => 1,
				'date' => 0,
				'days' => 30,
				'box_layout' => 'horizontal-small',
				'show_excerpt' => 0,
				'excerpt_length' => 10,
			);
			$instance = wp_parse_args((array) $instance, $defaults);
			$title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : __( 'Popular Posts', 'myblog' );
			$title_length = isset( $instance[ 'title_length' ] ) ? intval( $instance[ 'title_length' ] ) : 20;
			$image_type = $instance['image_type'];
			$qty = isset( $instance[ 'qty' ] ) ? intval( $instance[ 'qty' ] ) : 5;
			$author_name = isset( $instance[ 'author_name' ] ) ? intval( $instance[ 'author_name' ] ) : 1;
			$date = isset( $instance[ 'date' ] ) ? intval( $instance[ 'date' ] ) : 1;
			$days = isset( $instance[ 'days' ] ) ? intval( $instance[ 'days' ] ) : 30;
			$box_layout = $instance['box_layout'];
			$show_excerpt = isset( $instance[ 'show_excerpt' ] ) ? esc_attr( $instance[ 'show_excerpt' ] ) : 1;
			$excerpt_length = isset( $instance[ 'excerpt_length' ] ) ? intval( $instance[ 'excerpt_length' ] ) : 10;
			?>
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'myblog' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('image_type'); ?>"><?php _e('Image Type:', 'myblog' ); ?></label><br>
				<select id="<?php echo $this->get_field_id('image_type'); ?>" name="<?php echo $this->get_field_name('image_type'); ?>">
					<option value="featured_img" <?php selected($image_type, 'featured_img', true); ?>><?php _e('Featured Image', 'myblog' ); ?></option>
					<option value="author_img" <?php selected($image_type, 'author_img', true); ?>><?php _e('Author Image', 'myblog' ); ?></option>
					<option value="no_img" <?php selected($image_type, 'no_img', true); ?>><?php _e('No Image', 'myblog' ); ?></option>
				</select>
			</p>
			
			<p>
			   <label for="<?php echo $this->get_field_id( 'days' ); ?>"><?php _e( 'Popular limit (days):', 'myblog' ); ?>
			   <input id="<?php echo $this->get_field_id( 'days' ); ?>" name="<?php echo $this->get_field_name( 'days' ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $days ); ?>" />
			   </label>
		   </p>
		   
			<p>
				<label for="<?php echo $this->get_field_id( 'qty' ); ?>"><?php _e( 'Number of Posts to show', 'myblog' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'qty' ); ?>" name="<?php echo $this->get_field_name( 'qty' ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $qty ); ?>" />
			</p>

			<p>
			   <label for="<?php echo $this->get_field_id( 'title_length' ); ?>"><?php _e( 'Title Length:', 'myblog' ); ?>
			   <input id="<?php echo $this->get_field_id( 'title_length' ); ?>" name="<?php echo $this->get_field_name( 'title_length' ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $title_length ); ?>" />
			   </label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('box_layout'); ?>"><?php _e('Posts layout:', 'myblog' ); ?><br><span style="font-style: italic; margin-bottom: 5px; float: left; width: 100%;"><?php _e('Not applicable for Author Image Type', 'myblog' ); ?></span></label>
				<select id="<?php echo $this->get_field_id('box_layout'); ?>" name="<?php echo $this->get_field_name('box_layout'); ?>">
					<option value="horizontal-small" <?php selected($box_layout, 'horizontal-small', true); ?>><?php _e('Horizontal', 'myblog' ); ?></option>
					<option value="vertical-small" <?php selected($box_layout, 'vertical-small', true); ?>><?php _e('Vertical', 'myblog' ); ?></option>
				</select>
			</p>
			
			<p>
				<label for="<?php echo $this->get_field_id("date"); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("date"); ?>" name="<?php echo $this->get_field_name("date"); ?>" value="1" <?php if (isset($instance['date'])) { checked( 1, $instance['date'], true ); } ?> />
					<?php _e( 'Show post date', 'myblog' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id("author_name"); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("author_name"); ?>" name="<?php echo $this->get_field_name("author_name"); ?>" value="1" <?php checked( 1, $instance['author_name'], true ); ?> />
					<?php _e( 'Show Author Name', 'myblog' ); ?>
				</label>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id("show_excerpt"); ?>">
					<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("show_excerpt"); ?>" name="<?php echo $this->get_field_name("show_excerpt"); ?>" value="1" <?php checked( 1, $instance['show_excerpt'], true ); ?> />
					<?php _e( 'Show excerpt', 'myblog' ); ?>
				</label>
			</p>
			
			<p>
			   <label for="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"><?php _e( 'Excerpt Length:', 'myblog' ); ?>
			   <input id="<?php echo $this->get_field_id( 'excerpt_length' ); ?>" name="<?php echo $this->get_field_name( 'excerpt_length' ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $excerpt_length ); ?>" />
			   </label>
		   </p>
			<?php 
		}

		public function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = strip_tags( $new_instance['title'] );
			$instance['qty'] = intval( $new_instance['qty'] );
			$instance['title_length'] = intval( $new_instance['title_length'] );
			$instance['image_type'] = $new_instance['image_type'];
			$instance['author_name'] = intval( $new_instance['author_name'] );
			$instance['date'] = intval( $new_instance['date'] );
			$instance['days'] = intval( $new_instance['days'] );
			$instance['box_layout'] = $new_instance['box_layout'];
			$instance['show_excerpt'] = intval( $new_instance['show_excerpt'] );
			$instance['excerpt_length'] = intval( $new_instance['excerpt_length'] );
			return $instance;
		}

		public function widget( $args, $instance ) {
			extract( $args );
			$title = apply_filters( 'widget_title', $instance['title'] );
			$title_length = $instance['title_length'];
			$image_type = isset($instance['image_type']) ? $instance['image_type'] : 'author_img';
			$author_name = $instance['author_name'];
			$date = $instance['date'];
			$days = $instance['days'];
			$qty = (int) $instance['qty'];
			$box_layout = isset($instance['box_layout']) ? $instance['box_layout'] : 'horizontal-small';
			$show_excerpt = $instance['show_excerpt'];
			$excerpt_length = $instance['excerpt_length'];

			$before_widget = preg_replace('/class="([^"]+)"/i', 'class="$1 '.(isset($instance['box_layout']) ? $instance['box_layout'] : 'horizontal-small').'"', $before_widget); // Add horizontal/vertical class to widget
			echo $before_widget;
			if ( ! empty( $title ) ) echo $before_title . $title . $after_title;
			echo self::get_popular_posts( $qty, $title_length, $image_type, $author_name, $date, $days, $box_layout, $show_excerpt, $excerpt_length );
			echo $after_widget;
		}

		public function get_popular_posts( $qty, $title_length, $image_type, $author_name, $date, $days, $box_layout, $show_excerpt, $excerpt_length ) {
			
			if($image_type == 'no_img') {
				$no_image = ' no-thumb';
			} else {
				$no_image = '';
			}

			if ( 'horizontal-small' === $box_layout ) {
				$thumbnail	 = 'widgetthumb';
				$open_li_item  = '<li class="post-box horizontal-small horizontal-container '.$image_type.' '.$no_image.'"><div class="horizontal-container-inner">';
				$close_li_item = '</div></li>';
			} else {
				$thumbnail	 = 'widgetfull';
				$open_li_item  = '<li class="post-box vertical-small '.$image_type.' '.$no_image.'">';
				$close_li_item = '</li>';
			}

			$popular_days = array();
			if ( $days ) {
				$popular_days = array(
					//set date ranges
					'after' => "$days day ago",
					'before' => 'today',
					//allow exact matches to be returned
					'inclusive' => true,
				);
			}

			global $post;
			
			$popular = get_posts( array( 
				'suppress_filters' => false, 
				'ignore_sticky_posts' => 1, 
				'orderby' => 'comment_count', 
				'numberposts' => $qty,
				'date_query' => $popular_days) );

			echo '<ul class="popular-posts">';
			foreach($popular as $post) :
				setup_postdata($post);
			?>
				<?php echo $open_li_item; ?>
					<?php if ( $image_type != 'no_img' ) : ?>
						<div class="post-img">
							<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>">
								<?php if( $image_type == 'author_img' ) {
									echo get_avatar( get_the_author_meta('email'), 36 );
								} elseif( $image_type == 'featured_img' ) {
									if ( has_post_thumbnail() ) {
										the_post_thumbnail( 'myblog-' . $thumbnail, array( 'title' => '' ) );
									} else { ?>
										<img class="wp-post-image" src="<?php echo get_template_directory_uri() . '/images/nothumb-myblog-' . $thumbnail . '.png'; ?>" alt="<?php echo esc_attr( get_the_title() ); ?>"/>
									<?php }
								} ?>
							</a>
						</div>
					<?php endif; ?>
					<div class="post-data">
						<div class="post-data-container">
							<div class="post-title">
								<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>"><?php echo esc_html( mts_truncate( get_the_title(), $title_length, 'words' ) ); ?></a>
							</div>
							<?php if ( $date == 1 || $author_name == 1 ) : ?>
							<div class="post-info">
								<?php if ( $date == 1 ) : ?>
									<span class="thetime updated"><?php the_time( get_option( 'date_format' ) ); ?></span>
								<?php endif; ?>
								<?php if ( $author_name == 1 ) : ?>
									<span class="theauthor"><?php the_author_meta( 'display_name' ); ?></span>
								<?php endif; ?>
							</div> <!--end .post-info-->
							<?php endif; ?>
							<?php if ( $show_excerpt == 1 ) : ?>
							<div class="post-excerpt">
								<?php echo mts_excerpt( $excerpt_length ); ?>
							</div>
							<?php endif; ?>
						</div>
					</div>
				<?php echo $close_li_item; ?>
			<?php endforeach; wp_reset_postdata();
			echo '</ul>'."\r\n";
		}

	}
}
// Register widget
add_action( 'widgets_init', 'register_mts_popular_posts_widget' );
function register_mts_popular_posts_widget() {
	register_widget( 'mts_popular_posts_widget' );
}
