<?php

defined('ABSPATH') or die;

/*
 * 
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 * 
 * Add support tab
 *
 */
if ( ! defined('MTS_THEME_WHITE_LABEL') || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 * 
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constants for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){
	
	//$sections = array();
	$sections[] = array(
		'title' => __('A Section added by hook', 'myblog' ),
		'desc' => '<p class="description">' . __('This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'myblog' ) . '</p>',
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it blank for default.
		'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
		//Lets leave this as a blank section, no options just some intro text set above.
		'fields' => array()
	);
	
	return $sections;
	
}//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 * 
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){
	
	//$args['dev_mode'] = false;
	
	return $args;
	
}//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the options page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be overridden if needed.
 *
 *
 */

function setup_framework_options(){
	$args = array();

	//Set it to dev mode to view the class settings/info in the form - default is false
	$args['dev_mode'] = false;
	//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
	//$args['stylesheet_override'] = true;

	//Add HTML before the form
	//$args['intro_text'] = __('<p>This is the HTML which can be displayed before the form, it isnt required, but more info is always better. Anything goes in terms of markup here, any HTML.</p>', 'myblog' );

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Setup custom links in the footer for share icons
		$args['share_icons']['twitter'] = array(
			'link' => 'http://twitter.com/mythemeshopteam',
			'title' => __( 'Follow Us on Twitter', 'myblog' ),
			'img' => 'fa fa-twitter-square'
		);
		$args['share_icons']['facebook'] = array(
			'link' => 'http://www.facebook.com/mythemeshop',
			'title' => __( 'Like us on Facebook', 'myblog' ),
			'img' => 'fa fa-facebook-square'
		);
	}

	//Choose to disable the import/export feature
	//$args['show_import_export'] = false;

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
	$args['opt_name'] = MTS_THEME_NAME;

	//Custom menu icon
	//$args['menu_icon'] = '';

	//Custom menu title for options page - default is "Options"
	$args['menu_title'] = __('Theme Options', 'myblog' );

	//Custom Page Title for options page - default is "Options"
	$args['page_title'] = __('Theme Options', 'myblog' );

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
	$args['page_slug'] = 'theme_options';

	//Custom page capability - default is set to "manage_options"
	//$args['page_cap'] = 'manage_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
	//$args['page_type'] = 'submenu';

	//parent menu - default is set to "themes.php" (Appearance)
	//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	//$args['page_parent'] = 'themes.php';

	//custom page location - default 100 - must be unique or will override other items
	$args['page_position'] = 62;

	//Custom page icon class (used to override the page icon next to heading)
	//$args['page_icon'] = 'icon-themes';

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-1',
			'title' => __('Support', 'myblog' ),
			'content' => '<p>' . sprintf( __('If you are facing any problem with our theme or theme option panel, head over to our %s.', 'myblog' ), '<a href="http://community.mythemeshop.com/">'. __( 'Support Forums', 'myblog' ) . '</a>' ) . '</p>'
		);
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-2',
			'title' => __('Earn Money', 'myblog' ),
			'content' => '<p>' . sprintf( __('Earn 55%% commision on every sale by refering your friends and readers. Join our %s.', 'myblog' ), '<a href="http://mythemeshop.com/affiliate-program/">' . __( 'Affiliate Program', 'myblog' ) . '</a>' ) . '</p>'
		);
	}

	//Set the Help Sidebar for the options page - no sidebar by default										
	//$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'myblog' );

	$mts_patterns = array(
		'nobg' => array('img' => NHP_OPTIONS_URL.'img/patterns/nobg.png'),
		'pattern0' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern0.png'),
		'pattern1' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern1.png'),
		'pattern2' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern2.png'),
		'pattern3' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern3.png'),
		'pattern4' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern4.png'),
		'pattern5' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern5.png'),
		'pattern6' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern6.png'),
		'pattern7' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern7.png'),
		'pattern8' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern8.png'),
		'pattern9' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern9.png'),
		'pattern10' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern10.png'),
		'pattern11' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern11.png'),
		'pattern12' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern12.png'),
		'pattern13' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern13.png'),
		'pattern14' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern14.png'),
		'pattern15' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern15.png'),
		'pattern16' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern16.png'),
		'pattern17' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern17.png'),
		'pattern18' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern18.png'),
		'pattern19' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern19.png'),
		'pattern20' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern20.png'),
		'pattern21' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern21.png'),
		'pattern22' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern22.png'),
		'pattern23' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern23.png'),
		'pattern24' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern24.png'),
		'pattern25' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern25.png'),
		'pattern26' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern26.png'),
		'pattern27' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern27.png'),
		'pattern28' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern28.png'),
		'pattern29' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern29.png'),
		'pattern30' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern30.png'),
		'pattern31' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern31.png'),
		'pattern32' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern32.png'),
		'pattern33' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern33.png'),
		'pattern34' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern34.png'),
		'pattern35' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern35.png'),
		'pattern36' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern36.png'),
		'pattern37' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern37.png'),
		'hbg' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg.png'),
		'hbg2' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg2.png'),
		'hbg3' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg3.png'),
		'hbg4' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg4.png'),
		'hbg5' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg5.png'),
		'hbg6' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg6.png'),
		'hbg7' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg7.png'),
		'hbg8' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg8.png'),
		'hbg9' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg9.png'),
		'hbg10' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg10.png'),
		'hbg11' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg11.png'),
		'hbg12' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg12.png'),
		'hbg13' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg13.png'),
		'hbg14' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg14.png'),
		'hbg15' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg15.png'),
		'hbg16' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg16.png'),
		'hbg17' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg17.png'),
		'hbg18' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg18.png'),
		'hbg19' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg19.png'),
		'hbg20' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg20.png'),
		'hbg21' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg21.png'),
		'hbg22' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg22.png'),
		'hbg23' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg23.png'),
		'hbg24' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg24.png'),
		'hbg25' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg25.png')
	);

	$sections = array();

	$sections[] = array(
		'icon' => 'fa fa-cogs',
		'title' => __('General Settings', 'myblog' ),
		'desc' => '<p class="description">' . __('This tab contains common setting options which will be applied to the whole theme.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_logo',
				'type' => 'upload',
				'title' => __('Logo Image', 'myblog' ),
				'sub_desc' => __('Upload your logo using the Upload Button or insert image URL.', 'myblog' )
			),
			array(
				'id' => 'mts_favicon',
				'type' => 'upload',
				'title' => __('Favicon', 'myblog' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s favicon.', 'myblog' ), '<strong>32 x 32 px</strong>' )
			),
			array(
				'id' => 'mts_touch_icon',
				'type' => 'upload',
				'title' => __('Touch icon', 'myblog' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', 'myblog' ), '<strong>152 x 152 px</strong>' )
			),
			array(
				'id' => 'mts_metro_icon',
				'type' => 'upload',
				'title' => __('Metro icon', 'myblog' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s IE 10 Metro tile icon.', 'myblog' ), '<strong>144 x 144 px</strong>' )
			),
			array(
				'id' => 'mts_twitter_username',
				'type' => 'text',
				'title' => __('Twitter Username', 'myblog' ),
				'sub_desc' => __('Enter your Username here.', 'myblog' ),
			),
			array(
				'id' => 'mts_feedburner',
				'type' => 'text',
				'title' => __('FeedBurner URL', 'myblog' ),
				'sub_desc' => sprintf( __('Enter your FeedBurner\'s URL here, ex: %s and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', 'myblog' ), '<strong>http://feeds.feedburner.com/mythemeshop</strong>' ),
				'validate' => 'url'
			),
			array(
				'id' => 'mts_header_code',
				'type' => 'textarea',
				'title' => __('Header Code', 'myblog' ),
				'sub_desc' => wp_kses( __('Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'myblog' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_analytics_code',
				'type' => 'textarea',
				'title' => __('Footer Code', 'myblog' ),
				'sub_desc' => wp_kses( __('Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'myblog' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_pagenavigation_type',
				'type' => 'radio',
				'title' => __('Pagination Type', 'myblog' ),
				'sub_desc' => __('Select pagination type.', 'myblog' ),
				'options' => array(
					'0'=> __('Default (Next / Previous)', 'myblog' ),
					'1' => __('Numbered (1 2 3 4...)', 'myblog' ),
					'2' => __( 'AJAX (Load More Button)', 'myblog' ),
					'3' => __( 'AJAX (Auto Infinite Scroll)', 'myblog' ) 
				),
				'std' => '0'
			),
			array(
				'id' => 'mts_ajax_search',
				'type' => 'button_set',
				'title' => __('AJAX Quick search', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Enable or disable search results appearing instantly below the search form', 'myblog' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_responsive',
				'type' => 'button_set',
				'title' => __('Responsiveness', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', 'myblog' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_shop_products',
				'type' => 'text',
				'title' => __('No. of Products', 'myblog' ),
				'sub_desc' => __('Enter the total number of products which you want to show on shop page (WooCommerce plugin must be enabled).', 'myblog' ),
				'validate' => 'numeric',
				'std' => '9',
				'class' => 'small-text'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bolt',
		'title' => __('Performance', 'myblog' ),
		'desc' => '<p class="description">' . __('This tab contains performance-related options which can help speed up your website.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_prefetching',
				'type' => 'button_set',
				'title' => __('Prefetching', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', 'myblog' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_lazy_load',
				'type' => 'button_set_hide_below',
				'title' => __('Theme\'s Lazy Loading', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Delay loading of images outside of viewport, until user scrolls to them.', 'myblog' ),
				'std' => '0',
				'args' => array('hide' => 2)
				),
				array(
					'id' => 'mts_lazy_load_thumbs',
					'type' => 'button_set',
					'title' => __('Lazy load featured images', 'myblog' ),
					'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
					'sub_desc' => __('Enable or disable Lazy load of featured images across site.', 'myblog' ),
					'std' => '0'
				),
				array(
					'id' => 'mts_lazy_load_content',
					'type' => 'button_set',
					'title' => __('Lazy load post content images', 'myblog' ),
					'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
					'sub_desc' => __('Enable or disable Lazy load of images inside post/page content.', 'myblog' ),
					'std' => '0'
			),
			array(
				'id' => 'mts_async_js',
				'type' => 'button_set',
				'title' => __('Async JavaScript', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Add %s attribute to script tags to improve page download speed.', 'myblog' ), '<code>async</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_remove_ver_params',
				'type' => 'button_set',
				'title' => __('Remove ver parameters', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Remove %s parameter from CSS and JS file calls. It may improve speed in some browsers which do not cache files having the parameter.', 'myblog' ), '<code>ver</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_optimize_wc',
				'type' => 'button_set',
				'title' => __('Optimize WooCommerce scripts', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Load WooCommerce scripts and styles only on WooCommerce pages (WooCommerce plugin must be enabled).', 'myblog' ),
				'std' => '1'
			),
			'cache_message' => array(
				'id' => 'mts_cache_message',
				'type' => 'info',
				'title' => __('Use Cache', 'myblog' ),
				// Translators: %1$s = popup link to W3 Total Cache, %2$s = popup link to WP Super Cache
				'desc' => sprintf(
					__('A cache plugin can increase page download speed dramatically. We recommend using %1$s or %2$s.', 'myblog' ),
					'<a href="https://community.mythemeshop.com/tutorials/article/8-make-your-website-load-faster-using-w3-total-cache-plugin/" target="_blank" title="W3 Total Cache">W3 Total Cache</a>',
					'<a href="'.admin_url( 'plugin-install.php?tab=plugin-information&plugin=wp-super-cache&TB_iframe=true&width=772&height=574' ).'" class="thickbox" title="WP Super Cache">WP Super Cache</a>'
				),
			),
		)
	);

	// Hide cache message on multisite or if a cache plugin is active already
	if ( is_multisite() || strstr( join( ';', get_option( 'active_plugins' ) ), 'cache' ) ) {
		unset( $sections[1]['fields']['cache_message'] );
	}

	$sections[] = array(
		'icon' => 'fa fa-adjust',
		'title' => __('Styling Options', 'myblog' ),
		'desc' => '<p class="description">' . __('Control the visual appearance of your theme, such as colors, layout and patterns, from here.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_color_scheme',
				'type' => 'color',
				'title' => __('Color Scheme', 'myblog' ),
				'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', 'myblog' ),
				'std' => '#12b075'
			),
			array(
				'id' => 'mts_layout',
				'type' => 'radio_img',
				'title' => __('Sidebar Position', 'myblog' ),
				'sub_desc' => wp_kses( __('Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', 'myblog' ), array( 'strong' => array() ) ),
				'options' => array(
					'cslayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/cs.png'),
					'sclayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/sc.png')
				),
				'std' => 'cslayout'
			),
			array(
				'id' => 'mts_background',
				'type' => 'background',
				'title' => __('Site Background', 'myblog' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'myblog' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#fafafa',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_custom_css',
				'type' => 'textarea',
				'title' => __('Custom CSS', 'myblog' ),
				'sub_desc' => __('You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'myblog' )
			),
			array(
				'id' => 'mts_lightbox',
				'type' => 'button_set',
				'title' => __('Lightbox', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', 'myblog' ),
				'std' => '0'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-credit-card',
		'title' => __('Header', 'myblog' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of header section.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_header_section2',
				'type' => 'button_set',
				'title' => __('Show Logo', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide the <strong>Logo</strong> completely.', 'myblog' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_slider',
				'type' => 'button_set_hide_below',
				'title' => __('Header carousel', 'myblog'), 
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => wp_kses( __('<strong>Enable or Disable</strong> Header carousel with this button. The slider will show recent articles from the selected categories.', 'myblog' ), array( 'strong' => array() ) ),
				'std' => '0',
				'args' => array('hide' => 3)
				),
				array(
				'id' => 'mts_header_slider_single',
				'type' => 'button_set',
				'title' => __('Header carousel on Single Posts', 'myblog'), 
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => wp_kses( __('<strong>Enable or Disable</strong> Header carousel on single Posts.', 'myblog' ), array( 'strong' => array() ) ),
				'std' => '0'
				),
				array(
				'id' => 'mts_header_slider_cat',
				'type' => 'cats_multi_select',
				'title' => __('Header Carousel Category(s)', 'myblog'),
				'sub_desc' => wp_kses( __('Select a category from the drop-down menu, latest articles from this category will be shown <strong>in the slider</strong>.', 'myblog' ), array( 'strong' => array() ) ),
				),
				array(
				'id' => 'mts_header_slider_num',
				'type' => 'text',
				'class' => 'small-text',
				'title' => __('Header Carousel No. of posts', 'myblog'), 
				'sub_desc' => __('Enter the number of posts to show in the carousel', 'myblog'),
				'std' => '6',
				'args' => array('type' => 'number')
			),	
			array(
				'id' => 'mts_sticky_nav',
				'type' => 'button_set_hide_below',
				'title' => __('Floating Navigation Menu', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'myblog' ), '<strong>' . __('Floating Navigation Menu', 'myblog' ) . '</strong>' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_sticky_nav_scroll',
				'type' => 'button_set',
				'title' => __('Show/Hide on scroll', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Show/Hide %s on scroll', 'myblog' ), '<strong>' . __('Floating Navigation Menu', 'myblog' ) . '</strong>' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_show_primary_nav',
				'type' => 'button_set_hide_below',
				'title' => __('Show Primary Menu', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'myblog' ), '<strong>' . __( 'Primary Navigation Menu', 'myblog' ) . '</strong>' ),
				'std' => '1',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_primary_nav_login',
				'type' => 'button_set',
				'title' => __('Show Login URL', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s in the Navigation.', 'myblog' ), '<strong>' . __( 'Login URL', 'myblog' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_primary_nav_register',
				'type' => 'button_set',
				'title' => __('Show Register URL', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s in the Navigation.', 'myblog' ), '<strong>' . __( 'Register URL', 'myblog' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_search',
				'type' => 'button_set',
				'title' => __('Show Header Search Form', 'myblog'), 
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Use this button to Show or Hide <strong>Header Search Form</strong>.', 'myblog'),
				'std' => '1'
			),
			array(
				'id' => 'mts_social_icon_head',
				'type' => 'button_set_hide_below',
				'title' => __('Social Icons', 'myblog'),
				'sub_desc' => __('You can control header social icon from here', 'myblog'),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1',
				'args' => array('hide' => '1')
			),
			array(
			 	'id' => 'mts_header_social',
			 	'title' => __('Header Social Icons', 'myblog'), 
			 	'sub_desc' => __( 'Add Social Media icons in header.', 'myblog' ),
			 	'type' => 'group',
			 	'groupname' => __('Header Icons', 'myblog'), // Group name
			 	'subfields' => array(
					array(
						'id' => 'mts_header_icon_title',
						'type' => 'text',
						'title' => __('Title', 'myblog'), 
					),
					array(
						'id' => 'mts_header_icon',
						'type' => 'icon_select',
						'title' => __('Icon', 'myblog')
					),
					array(
						'id' => 'mts_header_icon_color',
						'type' => 'color',
						'title' => __('Color', 'myblog')
					),
					array(
						'id' => 'mts_header_icon_hover_color',
						'type' => 'color',
						'title' => __('Hover Color', 'myblog')
					),
					array(
						'id' => 'mts_header_icon_link',
						'type' => 'text',
						'title' => __('URL', 'myblog'), 
					),
				),
				'std' => array(
					'facebook' => array(
						'group_title' => 'Facebook',
						'group_sort' => '1',
						'mts_header_icon_title' => 'Facebook',
						'mts_header_icon' => 'facebook-square',
						'mts_header_icon_color' => '#5d82d1',
						'mts_header_icon_hover_color' => '#5d82d1',
						'mts_header_icon_link' => '#',
					),
					'twitter' => array(
						'group_title' => 'Twitter',
						'group_sort' => '2',
						'mts_header_icon_title' => 'Twitter',
						'mts_header_icon' => 'twitter-square',
						'mts_header_icon_color' => '#40bff5',
						'mts_header_icon_hover_color' => '#40bff5',
						'mts_header_icon_link' => '#',
					),
					'gplus' => array(
						'group_title' => 'Google Plus',
						'group_sort' => '3',
						'mts_header_icon_title' => 'Google Plus',
						'mts_header_icon' => 'google-plus-square',
						'mts_header_icon_color' => '#eb5e4c',
						'mts_header_icon_hover_color' => '#eb5e4c',
						'mts_header_icon_link' => '#',
					)
				)
			),
			array(
				'id' => 'mts_blog_author_background',
				'type' => 'background',
				'title' => __('Header Background', 'myblog' ),
				'sub_desc' => __('Set Header Background color, pattern and image from here.', 'myblog' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_navigation_background',
				'type' => 'background',
				'title' => __('Navigation Background', 'myblog' ),
				'sub_desc' => __('Set navigation background color, pattern and image from here.', 'myblog' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-table',
		'title' => __('Footer', 'myblog' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of Footer section.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_first_footer',
				'type' => 'button_set_hide_below',
				'title' => __('Footer Widget', 'myblog' ),
				'sub_desc' => __('Enable or disable footer widget with this option.', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '0'
				),
				array(
					'id' => 'mts_first_footer_num',
					'type' => 'button_set',
					'class' => 'green',
					'title' => __('Footer Widget Layout', 'myblog' ),
					'sub_desc' => wp_kses( __('Choose the number of widget areas in the <strong>footer</strong>', 'myblog' ), array( 'strong' => array() ) ),
					'options' => array(
						'3' => __( '3 Widgets', 'myblog' ),
						'4' => __( '4 Widgets', 'myblog' ),
					),
					'std' => '4'
			),
			array(
				'id' => 'mts_footer_background',
				'type' => 'background',
				'title' => __('Footer Widget Background', 'myblog' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'myblog' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_copyright_background',
				'type' => 'background',
				'title' => __('Copyright Background', 'myblog' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'myblog' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#fafafa',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_copyrights',
				'type' => 'textarea',
				'title' => __('Copyrights Text', 'myblog' ),
				'sub_desc' => __( 'You can change or remove our link from footer and use your own custom text.', 'myblog' ) . ( MTS_THEME_WHITE_LABEL ? '' : wp_kses( __('(You can also use your affiliate link to <strong>earn 55% of sales</strong>. Ex: <a href="https://mythemeshop.com/go/aff/aff" target="_blank">https://mythemeshop.com/?ref=username</a>)', 'myblog' ), array( 'strong' => array(), 'a' => array( 'href' => array(), 'target' => array() ) ) ) ),
				'std' => MTS_THEME_WHITE_LABEL ? null : sprintf( __( 'Theme Designed by %s', 'myblog' ), '<a href="http://mythemeshop.com/" rel="nofollow">MyThemeShop.com</a>' )
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-home',
		'title' => __('Homepage', 'myblog' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of the homepage.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_home_layout',
				'type' => 'radio_img',
				'title' => __('Select Layout for Homepage', 'myblog' ),
				'sub_desc' => wp_kses( __('Choose the layout for homepage posts.', 'myblog' ), array( 'strong' => array() ) ),
				'options' => array(
					'full-width' => array('img' => NHP_OPTIONS_URL.'img/layouts/home-layout.jpg'), // Full Width
					'left-thumb' => array('img' => NHP_OPTIONS_URL.'img/layouts/home-layout-2.jpg'),  // Left Thumb
					'right-thumb' => array('img' => NHP_OPTIONS_URL.'img/layouts/home-layout-3.jpg'),  // Right Thumb
				),
				'std' => 'left-thumb'
			),
			array(
				'id' => 'mts_featured_slider',
				'type' => 'button_set_hide_below',
				'title' => __('Homepage Slider', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => wp_kses( __('<strong>Enable or Disable</strong> homepage slider with this button. The slider will show recent articles from the selected categories.', 'myblog' ), array( 'strong' => array() ) ),
				'std' => '0',
				'args' => array('hide' => 3)
				),
				array(
					'id' => 'mts_featured_slider_cat',
					'type' => 'cats_multi_select',
					'title' => __('Slider Category(s)', 'myblog' ),
					'sub_desc' => wp_kses( __('Select a category from the drop-down menu, latest articles from this category will be shown <strong>in the slider</strong>.', 'myblog' ), array( 'strong' => array() ) ),
				),
				array(
					'id' => 'mts_featured_slider_num',
					'type' => 'text',
					'class' => 'small-text',
					'title' => __('Number of posts', 'myblog' ),
					'sub_desc' => __('Enter the number of posts to show in the slider', 'myblog' ),
					'std' => '3',
					'args' => array('type' => 'number')
				),	
				array(
					'id' => 'mts_custom_slider',
					'type' => 'group',
					'title' => __('Custom Slider', 'myblog' ),
					'sub_desc' => __('With this option you can set up a slider with custom image and text instead of the default slider automatically generated from your posts.', 'myblog' ),
					'groupname' => __('Slider', 'myblog' ), // Group name
					'subfields' => 
					array(
						array(
							'id' => 'mts_custom_slider_title',
							'type' => 'text',
							'title' => __('Title', 'myblog' ),
							'sub_desc' => __('Title of the slide', 'myblog' ),
						),
						array(
							'id' => 'mts_custom_slider_image',
							'type' => 'upload',
							'title' => __('Image', 'myblog' ),
							'sub_desc' => __('Upload or select an image for this slide', 'myblog' ),
							'return' => 'id'
						),
						array('id' => 'mts_custom_slider_link',
							'type' => 'text',
							'title' => __('Link', 'myblog' ),
							'sub_desc' => __('Insert a link URL for the slide', 'myblog' ),
							'std' => '#'
						),
					),
			),
			array(
				'id' => 'mts_featured_categories',
				'type' => 'group',
				'title'	 => __('Featured Categories', 'myblog' ),
				'sub_desc'  => __('Select categories appearing on the homepage.', 'myblog' ),
				'groupname' => __('Section', 'myblog' ), // Group name
				'subfields' => 
					array(
						array(
							'id' => 'mts_featured_category',
							'type' => 'cats_select',
							'title' => __('Category', 'myblog' ),
							'sub_desc' => __('Select a category or the latest posts for this section', 'myblog' ),
							'std' => 'latest',
							'args' => array('include_latest' => 1, 'hide_empty' => 0),
						),
						array(
							'id' => 'mts_featured_category_postsnum',
							'type' => 'text',
							'class' => 'small-text',
							'title' => __('Number of posts', 'myblog' ),
							'sub_desc' => __('Enter the number of posts to show in this section.', 'myblog' ),
							'std' => '3',
							'args' => array('type' => 'number')
						),
				),
				'std' => array(
					'1' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_featured_category' => 'latest',
						'mts_featured_category_postsnum' => get_option('posts_per_page')
					)
				)
			),
			array(
				'id'	 => 'mts_home_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('HomePage Post Meta Info', 'myblog' ),
				'sub_desc' => __('Organize how you want the post meta info to appear on the homepage', 'myblog' ),
				'options'  => array(
					'enabled'  => array(
						'author-image'   => __('Author Image', 'myblog' ),
						'author'   => __('Author Name', 'myblog' ),
						'date'	 => __('Date', 'myblog' )
					),
					'disabled' => array(
						'category' => __('Categories', 'myblog' ),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'author-image'   => __('Author Image', 'myblog' ),
						'author'   => __('Author Name', 'myblog' ),
						'date'	 => __('Date', 'myblog' )
					),
					'disabled' => array(
						'category' => __('Categories', 'myblog' )
					)
				)
			),
			array(
				'id' => 'mts_post_format_icons',
				'type' => 'button_set',
				'title' => __('Post Format Icons on Homepage', 'myblog' ), 
				'sub_desc' => __('Show Post Format Icons on Homepage Post', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_like_button',
				'type' => 'button_set',
				'title' => __('Post Like Button', 'myblog' ), 
				'sub_desc' => __('Show Post Like Button on Homepage & Single Post', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_home_comments',
				'type' => 'button_set',
				'title' => __('Comment Count on Homepage', 'myblog' ), 
				'sub_desc' => __('Show Comments on Homepage Post', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-file-text',
		'title' => __('Single Posts', 'myblog' ),
		'desc' => '<p class="description">' . __('From here, you can control the appearance and functionality of your single posts page.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id'	 => 'mts_single_post_layout',
				'type'	 => 'layout2',
				'title'	=> __('Single Post Layout', 'myblog' ),
				'sub_desc' => __('Customize the look of single posts', 'myblog' ),
				'options'  => array(
					'enabled'  => array(
						'content'   => array(
							'label' 	=> __('Post Content', 'myblog' ),
							'subfields'	=> array(
								
							)
						),
						'author'   => array(
							'label' 	=> __('Author Box', 'myblog' ),
							'subfields'	=> array()
						),
						'related'   => array(
							'label' 	=> __('Related Articles', 'myblog' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_related_posts_taxonomy',
									'type' => 'button_set',
									'title' => __('Related Articles Taxonomy', 'myblog' ) ,
									'options' => array(
										'tags' => __( 'Tags', 'myblog' ),
										'categories' => __( 'Categories', 'myblog' )
									) ,
									'class' => 'green',
									'sub_desc' => __('Related Articles based on tags or categories.', 'myblog' ) ,
									'std' => 'categories'
								),
								array(
									'id' => 'mts_related_postsnum',
									'type' => 'text',
									'class' => 'small-text',
									'title' => __('Number of related articles', 'myblog' ) ,
									'sub_desc' => __('Enter the number of posts to show in the related articles section.', 'myblog' ) ,
									'std' => '2',
									'args' => array(
										'type' => 'number'
									)
								),

							)
						),
					),
					'disabled' => array(
						'tags'   => array(
							'label' 	=> __('Tags', 'myblog' ),
							'subfields'	=> array(
							)
						)
					)
				)
			),
			array(
				'id'	 => 'mts_single_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('Meta Info to Show', 'myblog' ),
				'sub_desc' => __('Organize how you want the post meta info to appear', 'myblog' ),
				'options'  => array(
					'enabled'  => array(
						'author-image'   => __('Author Image', 'myblog' ),
						'author'   => __('Author Name', 'myblog' ),
						'date'	 => __('Date', 'myblog' )
					),
					'disabled' => array(
						'category' => __('Categories', 'myblog' ),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'author-image'   => __('Author Image', 'myblog' ),
						'author'   => __('Author Name', 'myblog' ),
						'date'	 => __('Date', 'myblog' )
					),
					'disabled' => array(
						'category' => __('Categories', 'myblog' )
					)
				)
			),
			array(
				'id' => 'mts_breadcrumb',
				'type' => 'button_set',
				'title' => __('Breadcrumbs', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'myblog' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_single_post_format_icons',
				'type' => 'button_set',
				'title' => __('Post Format Icons on Single Posts', 'myblog' ), 
				'sub_desc' => __('Show or hide Post Format Icons on Single posts', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_single_post_tags',
				'type' => 'button_set',
				'title' => __('Tags on Single Page', 'myblog' ), 
				'sub_desc' => __('Show Tags on Singlepage', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_single_comments',
				'type' => 'button_set',
				'title' => __('Comment Count', 'myblog' ), 
				'sub_desc' => __('Show Comment count on Single Post', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_related_time',
				'type' => 'button_set',
				'title' => __('Related Post Date', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('You can disable date of related post published.', 'myblog' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_author_comment',
				'type' => 'button_set',
				'title' => __('Highlight Author Comment', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Use this button to highlight author comments.', 'myblog' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_like_button',
				'type' => 'button_set',
				'title' => __('Comment Like Button', 'myblog' ), 
				'sub_desc' => __('Show Comment Like Button on Homepage', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_date',
				'type' => 'button_set',
				'title' => __('Date in Comments', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Use this button to show the date for comments.', 'myblog' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_ajax_single_load',
				'type' => 'button_set_hide_below',
				'title' => __('Infinite load', 'myblog' ),
				'options' => array( '0' => __( 'Off', 'myblog' ), '1' => __( 'On', 'myblog' ) ),
				'sub_desc' => __('Load next article using AJAX once the user scrolls to the end of the article.','myblog').' <strong style="color: #e0957e;">'.__('WARNING: This feature can conflict with few plugins/themes which make use of AJAX/JS. Once you activate this option, please make sure everything is working as expected.','myblog').'</strong>',
				'std' => '0',
				'args' => array('hide' => 2)
				),
				array(
					'id' => 'mts_ajax_single_load_type',
					'type' => 'button_set',
					'title' => __('Posts to load', 'myblog' ),
					'options' => array('all' => __('All Posts', 'myblog' ), 'category' => __('From same category', 'myblog' ), 'post_tag' => __('From same tag', 'myblog' )),
					'sub_desc' => __('Next post to load from.', 'myblog' ),
					'std' => 'all',
					'class' => 'green'
				),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-group',
		'title' => __('Social Buttons', 'myblog' ),
		'desc' => '<p class="description">' . __('Enable or disable social sharing buttons on single posts using these buttons.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_social_button_type',
				'type' => 'radio_img',
				'title' => __('Social Sharing Buttons Type', 'myblog' ),
				'options' => array(
					'icons' => array('img' => NHP_OPTIONS_URL.'img/layouts/modern-social.jpg'),
					'counter' => array('img' => NHP_OPTIONS_URL.'img/layouts/default-social.jpg')
				),
				'sub_desc' => __('Select Social Sharing Button type', 'myblog' ),
				'std' => 'icons',
				'class' => 'green'
			),
			array(
				'id' => 'mts_social_button_position',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons Position', 'myblog' ),
				'options' => array('top' => __('Above Content', 'myblog' ), 'bottom' => __('Below Content', 'myblog' ), 'floating' => __('Floating', 'myblog' )),
				'sub_desc' => __('Choose position for Social Sharing Buttons.', 'myblog' ),
				'std' => 'bottom',
				'class' => 'green'
			),
			array(
				'id' => 'mts_social_buttons_on_pages',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons on Pages', 'myblog' ),
				'options' => array('0' => __('Off', 'myblog' ), '1' => __('On', 'myblog' )),
				'sub_desc' => __('Enable the sharing buttons for pages too, not just posts.', 'myblog' ),
				'std' => '0',
			),
			array(
				'id'   => 'mts_social_buttons',
				'type' => 'layout',
				'title'	=> __('Social Media Buttons', 'myblog' ),
				'sub_desc' => __('Organize how you want the social sharing buttons to appear on single posts', 'myblog' ),
				'options'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'myblog' ),
						'facebook'  => __('Facebook Like', 'myblog' ),
						'twitter'   => __('Twitter', 'myblog' ),
						'gplus' => __('Google Plus', 'myblog' ),
						'pinterest' => __('Pinterest', 'myblog' ),
					),
					'disabled' => array(
						'linkedin'  => __('LinkedIn', 'myblog' ),
						'stumble'   => __('StumbleUpon', 'myblog' ),
						'reddit'   => __('Reddit', 'myblog' ),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'myblog' ),
						'facebook'  => __('Facebook Like', 'myblog' ),
						'twitter'   => __('Twitter', 'myblog' ),
						'gplus' => __('Google Plus', 'myblog' ),
						'pinterest' => __('Pinterest', 'myblog' ),
					),
					'disabled' => array(
						'linkedin'  => __('LinkedIn', 'myblog' ),
						'stumble'   => __('StumbleUpon', 'myblog' ),
						'reddit'   => __('Reddit', 'myblog' ),
					)
				),
				'reset_at_version' => '1.1.3'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bar-chart-o',
		'title' => __('Ad Management', 'myblog' ),
		'desc' => '<p class="description">' . __('Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'myblog' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_posttop_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Title', 'myblog' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'myblog' )
			),
			array(
				'id' => 'mts_posttop_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'myblog' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'myblog' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
			array(
				'id' => 'mts_postend_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Content', 'myblog' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'myblog' )
			),
			array(
				'id' => 'mts_postend_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'myblog' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'myblog' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-columns',
		'title' => __('Sidebars', 'myblog' ),
		'desc' => '<p class="description">' . __('Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.', 'myblog' ) . '<br></p>',
		'fields' => array(
			array(
				'id' => 'mts_sidebar_title_bg',
				'type' => 'color',
				'title' => __('Sidebar Title Background', 'myblog' ),
				'sub_desc' => __('Choose background color for sidebar widget titles', 'myblog' ),
				'std' => '#333333'
			),
			array(
				'id' => 'mts_custom_sidebars',
				'type'  => 'group', //doesn't need to be called for callback fields
				'title' => __('Custom Sidebars', 'myblog' ),
				'sub_desc'  => wp_kses( __('Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', 'myblog' ), array( 'strong' => array(), 'br' => array() ) ),
				'groupname' => __('Sidebar', 'myblog' ), // Group name
				'subfields' => 
					array(
						array(
							'id' => 'mts_custom_sidebar_name',
							'type' => 'text',
							'title' => __('Name', 'myblog' ),
							'sub_desc' => __('Example: Homepage Sidebar', 'myblog' )
						),	
						array(
							'id' => 'mts_custom_sidebar_id',
							'type' => 'text',
							'title' => __('ID', 'myblog' ),
							'sub_desc' => __('Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', 'myblog' ),
							'std' => 'sidebar-'
						),
					),
			),
			array(
				'id' => 'mts_sidebar_for_home',
				'type' => 'sidebars_select',
				'title' => __('Homepage', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the homepage.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_post',
				'type' => 'sidebars_select',
				'title' => __('Single Post', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_page',
				'type' => 'sidebars_select',
				'title' => __('Single Page', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_archive',
				'type' => 'sidebars_select',
				'title' => __('Archive', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_category',
				'type' => 'sidebars_select',
				'title' => __('Category Archive', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the category archives.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_tag',
				'type' => 'sidebars_select',
				'title' => __('Tag Archive', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the tag archives.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_date',
				'type' => 'sidebars_select',
				'title' => __('Date Archive', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the date archives.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_author',
				'type' => 'sidebars_select',
				'title' => __('Author Archive', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the author archives.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_search',
				'type' => 'sidebars_select',
				'title' => __('Search', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the search results.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_notfound',
				'type' => 'sidebars_select',
				'title' => __('404 Error', 'myblog' ),
				'sub_desc' => __('Select a sidebar for the 404 Not found pages.', 'myblog' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_shop',
				'type' => 'sidebars_select',
				'title' => __('Shop Pages', 'myblog' ),
				'sub_desc' => wp_kses( __('Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', 'myblog' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => 'shop-sidebar'
			),
			array(
				'id' => 'mts_sidebar_for_product',
				'type' => 'sidebars_select',
				'title' => __('Single Product', 'myblog' ),
				'sub_desc' => wp_kses( __('Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', 'myblog' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => 'product-sidebar'
			),
		),
	);

	$sections[] = array(
		'icon' => 'fa fa-list-alt',
		'title' => __('Navigation', 'myblog' ),
		'desc' => '<p class="description"><div class="controls">' . sprintf( __('Navigation settings can now be modified from the %s.', 'myblog' ), '<a href="nav-menus.php"><b>' . __( 'Menus Section', 'myblog' ) . '</b></a>' ) . '<br></div></p>'
	);

					
	$tabs = array();

	$args['presets'] = array();
	$args['show_translate'] = false;
	include('theme-presets.php');

	global $NHP_Options;
	$NHP_Options = new NHP_Options($sections, $args, $tabs);

} //function

add_action('init', 'setup_framework_options', 0);

/*
 * 
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 * 
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){
	
	$error = false;
	$value =  'just testing';
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;
	
}//function

/*--------------------------------------------------------------------
 * 
 * Default Font Settings
 *
 --------------------------------------------------------------------*/
if(function_exists('mts_register_typography')) { 
	mts_register_typography( array(
		'logo_font' => array(
			'preview_text' => __( 'Logo Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '500',
			'font_size' => '24px',
			'font_color' => '#333333',
			'css_selectors' => '#header h1 a, #header h2 a'
		),
		'navigation_font' => array(
			'preview_text' => __( 'Navigation Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#8f8f8f',
			'css_selectors' => '#secondary-navigation, #searchform.searchbox'
		),
		'home_title_font' => array(
			'preview_text' => __( 'Home Article Title', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '29px',
			'font_variant' => '700',
			'font_color' => '#333333',
			'css_selectors' => '.latestPost .title a'
		),
		'post_info_font' => array(
			'preview_text' => __( 'Small Fonts (Post Info etc)', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '14px',
			'font_variant' => 'normal',
			'font_color' => '#8f8f8f',
			'css_selectors' => '.post-info, .widget .wpt-postmeta, .breadcrumb, .ago, .tagtext, .sharemedia-readmore, .latestPost-review-wrapper, input, .pagination, #load-posts, .reply, .tags, .mts-like, .share-text'
		),
		'single_title_font' => array(
			'preview_text' => __( 'Single Article Title', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '29px',
			'font_variant' => '700',
			'font_color' => '#333333',
			'css_selectors' => '.single-title'
		),
		'content_font' => array(
			'preview_text' => __( 'Content Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Georgia, serif',
			'font_size' => '18px',
			'font_variant' => 'normal',
			'font_color' => '#333333',
			'css_selectors' => 'body'
		),
		'widget_font' => array(
			'preview_text' => __( 'Widget Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#8f8f8f',
			'css_selectors' => '.widget'
		),
		'widget_title_font' => array(
			'preview_text' => __( 'Widget Title Font', 'myblog' ),
			'preview_color' => 'dark',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#ffffff',
			'css_selectors' => '.widget .widget-title'
		),
		'widget_links_font' => array(
			'preview_text' => __( 'Widget Links Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#333333',
			'css_selectors' => '.widget a'
		),
		'footer_font' => array(
			'preview_text' => __( 'Footer Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#8f8f8f',
			'css_selectors' => '#site-footer'
		),
		'footer_widget_title_font' => array(
			'preview_text' => __( 'Footer Widget Title Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#8f8f8f',
			'css_selectors' => '#site-footer .widget .widget-title'
		),
		'footer_widget_links_font' => array(
			'preview_text' => __( 'Footer Widget Links Font', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#333333',
			'css_selectors' => '#site-footer .widget a'
		),
		'h1_headline' => array(
			'preview_text' => __( 'Content H1', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '29px',
			'font_color' => '#333333',
			'css_selectors' => 'h1'
		),
		'h2_headline' => array(
			'preview_text' => __( 'Content H2', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '27px',
			'font_color' => '#333333',
			'css_selectors' => 'h2'
		),
		'h3_headline' => array(
			'preview_text' => __( 'Content H3', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '25px',
			'font_color' => '#333333',
			'css_selectors' => 'h3'
		),
		'h4_headline' => array(
			'preview_text' => __( 'Content H4', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '23px',
			'font_color' => '#333333',
			'css_selectors' => 'h4'
		),
		'h5_headline' => array(
			'preview_text' => __( 'Content H5', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '21px',
			'font_color' => '#333333',
			'css_selectors' => 'h5'
		),
		'h6_headline' => array(
			'preview_text' => __( 'Content H6', 'myblog' ),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '19px',
			'font_color' => '#333333',
			'css_selectors' => 'h6'
		)
	));
}
